aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_json_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_json_lib.h')
-rw-r--r--src/include/taler_json_lib.h19
1 files changed, 15 insertions, 4 deletions
diff --git a/src/include/taler_json_lib.h b/src/include/taler_json_lib.h
index dd47feb12..0e8c8fc2b 100644
--- a/src/include/taler_json_lib.h
+++ b/src/include/taler_json_lib.h
@@ -151,7 +151,7 @@ TALER_JSON_pack_token_issue_sig (
struct GNUNET_JSON_PackSpec
TALER_JSON_pack_token_envelope (
const char *name,
- const struct TALER_TokenEnvelopeP *envelope);
+ const struct TALER_TokenEnvelope *envelope);
/**
@@ -209,6 +209,17 @@ TALER_JSON_pack_age_commitment (
/**
+ * Generate packer instruction of a KYC Trigger Event.
+ *
+ * @param name name of the field to add to the object
+ * @param event event type to add
+ * @return json pack specification
+ */
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_kycte (const char *name,
+ enum TALER_KYCLOGIC_KycTriggerEvent event);
+
+/**
* Convert a TALER amount to a JSON object.
*
* @param amount the amount
@@ -635,7 +646,7 @@ TALER_JSON_spec_blinded_token_issue_sig (
struct GNUNET_JSON_Specification
TALER_JSON_spec_token_envelope (
const char *field,
- struct TALER_TokenEnvelopeP *env);
+ struct TALER_TokenEnvelope *env);
/**
@@ -918,7 +929,7 @@ typedef void
* @param cb function to call on the result
* @param cb_cls closure for @a cb
* @param binary name of the binary to execute
* @param ... NULL-terminated list of arguments for the @a binary,
* usually starting with again the name of the binary
* @return handle to cancel the operation (and kill the helper)
*/
@@ -928,7 +939,7 @@ TALER_JSON_external_conversion_start (
TALER_JSON_JsonCallback cb,
void *cb_cls,
const char *binary,
- ...);
+ const char **argv);
/**
* Abort external conversion, killing the process and preventing
@@ -918,7 +929,7 @@ typedef void
* @param cb_cls closure for @a cb
* @param binary name of the binary to execute
- * @param ... NULL-terminated list of arguments for the @a binary,
+ * @param argv NULL-terminated list of arguments for the @a binary,
* usually starting with again the name of the binary
* @return handle to cancel the operation (and kill the helper)